import * as i0 from '@angular/core';
import { Injectable, Component, Input, NgModule } from '@angular/core';
import { ReplaySubject, merge, timer } from 'rxjs';
import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { finalize, partition, switchMap, debounce, distinctUntilChanged, tap } from 'rxjs/operators';
import * as i3 from '@angular/platform-browser';
import * as i22 from '@angular/common';
import { CommonModule } from '@angular/common';

class NgxHttpLoaderInterceptor {
    constructor() {
        this.reqStatus$ = new ReplaySubject(1);
        this.pendingReqCnt = 0;
        this.forceStop = false;
        this.filterUrls = [];
        this.filterUrlPatterns = [];
        this.filterMethods = [];
        this.filterHeaders = [];
    }
    get pendingRequestCnt() {
        return this.pendingRequestCnt;
    }
    get reqStatus() {
        return this.reqStatus$.asObservable();
    }
    set setFilterUrls(urls) {
        this.filterUrls = urls;
    }
    set setUrlPatterns(regx) {
        this.filterUrlPatterns = regx;
    }
    set setFilterMethods(methods) {
        this.filterMethods = methods;
    }
    set setFilterHeaders(headers) {
        this.filterHeaders = headers;
    }
    set setForceStopReq(bool) {
        this.forceStop = bool;
    }
    checkIsFilterUrl(url) {
        return this.filterUrls.some(x => x === url);
    }
    checkUrlPatterns(url) {
        return this.filterUrlPatterns.some(x => x.test(url));
    }
    checkHttpMethod(req) {
        return this.filterMethods.some(e => {
            return e.toLowerCase() === req.method.toLowerCase();
        });
    }
    checkReqHeader(req) {
        return this.filterHeaders.some(e => {
            return req.headers.has(e);
        });
    }
    isStopReq(r) {
        return this.forceStop
            || this.checkIsFilterUrl(r.urlWithParams)
            || this.checkUrlPatterns(r.urlWithParams)
            || this.checkHttpMethod(r)
            || this.checkReqHeader(r);
    }
    intercept(request, next) {
        const isNext = this.isStopReq(request);
        if (!isNext) {
            this.pendingReqCnt++;
            if (1 === this.pendingReqCnt) {
                this.reqStatus$.next(true);
            }
        }
        return next.handle(request).pipe(finalize(() => {
            if (!isNext) {
                this.pendingReqCnt--;
                if (0 === this.pendingReqCnt) {
                    this.reqStatus$.next(false);
                }
            }
        }));
    }
}
NgxHttpLoaderInterceptor.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderInterceptor, deps: [], target: i0.ɵɵFactoryTarget.Injectable });
NgxHttpLoaderInterceptor.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderInterceptor, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderInterceptor, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }] });
const RequestsInterceptorProvider = [{
        provide: HTTP_INTERCEPTORS,
        useExisting: NgxHttpLoaderInterceptor,
        multi: true
    }];

class NgxHttpLoaderService {
    constructor(reqService) {
        this.reqService = reqService;
        this.showLoader = new ReplaySubject(1);
    }
    get isShowLoader() {
        return this.showLoader.asObservable();
    }
    show() {
        this.reqService.setForceStopReq = true;
        this.showLoader.next(true);
    }
    hide() {
        this.showLoader.next(false);
        this.reqService.setForceStopReq = false;
    }
}
NgxHttpLoaderService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderService, deps: [{ token: NgxHttpLoaderInterceptor }], target: i0.ɵɵFactoryTarget.Injectable });
NgxHttpLoaderService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: NgxHttpLoaderInterceptor }]; } });

const NgxLoader = {
    DEFAULT: 'loader-default',
    CLOCK: 'loader-clock',
    DUALRING: 'loader-dual-ring',
    ELLIPSIS: 'loader-ellipsis',
    FACEBOOK: 'loader-facebook',
    GEAR: 'loader-gear',
    GRID: 'loader-grid',
    HEART: 'loader-heart',
    HOURGLASS: 'loader-hourglass',
    JELLYBOX: 'loader-jellybox',
    MULTICIRCLE: 'loader-multicicle',
    RING: 'loader-ring',
    RIPPLE: 'loader-ripple',
    ROLLER: 'loader-roller',
    SPINNER: 'loader-spinner',
    THREEBOUNCE: 'loader-three-bounce',
    WATERWAVE: 'loader-water-wave',
    ROTATINGPLANE: 'loader-rotating-plane',
};

class GearLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
GearLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: GearLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GearLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: GearLoaderComponent, selector: "lib-gear-loader", ngImport: i0, template: "<svg class=\"gear\" style=\"width:64px\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <path id=\"p\"\n        d=\"M94.1 58.8c.6-2.8.9-5.8.9-8.8s-.3-6-.9-8.8l-11.7-.4c-.7-2.6-1.7-5-3-7.3l8-8.5c-3.3-4.9-7.5-9.2-12.5-12.5l-8.5 8c-2.3-1.3-4.7-2.3-7.3-3l-.3-11.6C56 5.3 53 5 50 5s-6 .3-8.8.9l-.4 11.7c-2.6.7-5 1.7-7.3 3l-8.5-8c-4.9 3.3-9.2 7.5-12.5 12.5l8 8.5c-1.3 2.3-2.3 4.7-3 7.3l-11.6.3C5.3 44 5 47 5 50s.3 6 .9 8.8l11.7.4c.7 2.6 1.7 5 3 7.3l-8 8.5c3.3 4.9 7.5 9.2 12.5 12.5l8.5-8c2.3 1.3 4.7 2.3 7.3 3l.4 11.7c2.7.5 5.7.8 8.7.8s6-.3 8.8-.9l.4-11.7c2.6-.7 5-1.7 7.3-3l8.5 8c4.9-3.3 9.2-7.5 12.5-12.5l-8-8.5c1.3-2.3 2.3-4.7 3-7.3l11.6-.3zM50 66.9c-9.3 0-16.9-7.6-16.9-16.9S40.7 33.1 50 33.1 66.9 40.7 66.9 50 59.3 66.9 50 66.9z\">\n    </path>\n</svg>\n<svg class=\"gear\" style=\"width:88px;margin:64px 0 0 -12px;animation-direction:reverse\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <use href=\"#p\"></use>\n</svg>", styles: ["@keyframes r{0%{transform:rotate(0)}to{transform:rotate(45deg)}}svg.gear{animation:r .5s infinite linear;fill:var(--iconcolor)}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: GearLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-gear-loader', template: "<svg class=\"gear\" style=\"width:64px\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <path id=\"p\"\n        d=\"M94.1 58.8c.6-2.8.9-5.8.9-8.8s-.3-6-.9-8.8l-11.7-.4c-.7-2.6-1.7-5-3-7.3l8-8.5c-3.3-4.9-7.5-9.2-12.5-12.5l-8.5 8c-2.3-1.3-4.7-2.3-7.3-3l-.3-11.6C56 5.3 53 5 50 5s-6 .3-8.8.9l-.4 11.7c-2.6.7-5 1.7-7.3 3l-8.5-8c-4.9 3.3-9.2 7.5-12.5 12.5l8 8.5c-1.3 2.3-2.3 4.7-3 7.3l-11.6.3C5.3 44 5 47 5 50s.3 6 .9 8.8l11.7.4c.7 2.6 1.7 5 3 7.3l-8 8.5c3.3 4.9 7.5 9.2 12.5 12.5l8.5-8c2.3 1.3 4.7 2.3 7.3 3l.4 11.7c2.7.5 5.7.8 8.7.8s6-.3 8.8-.9l.4-11.7c2.6-.7 5-1.7 7.3-3l8.5 8c4.9-3.3 9.2-7.5 12.5-12.5l-8-8.5c1.3-2.3 2.3-4.7 3-7.3l11.6-.3zM50 66.9c-9.3 0-16.9-7.6-16.9-16.9S40.7 33.1 50 33.1 66.9 40.7 66.9 50 59.3 66.9 50 66.9z\">\n    </path>\n</svg>\n<svg class=\"gear\" style=\"width:88px;margin:64px 0 0 -12px;animation-direction:reverse\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <use href=\"#p\"></use>\n</svg>", styles: ["@keyframes r{0%{transform:rotate(0)}to{transform:rotate(45deg)}}svg.gear{animation:r .5s infinite linear;fill:var(--iconcolor)}\n"] }]
        }], ctorParameters: function () { return []; } });

class GridLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
GridLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: GridLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
GridLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: GridLoaderComponent, selector: "lib-grid-loader", ngImport: i0, template: "<div class=\"lds-grid\">\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n</div>", styles: [".lds-grid{display:inline-block;position:relative;width:80px;height:80px}.lds-grid div{position:absolute;width:16px;height:16px;border-radius:50%;background:var(--iconcolor);animation:lds-grid 1.2s linear infinite}.lds-grid div:nth-child(1){top:8px;left:8px;animation-delay:0s}.lds-grid div:nth-child(2){top:8px;left:32px;animation-delay:-.4s}.lds-grid div:nth-child(3){top:8px;left:56px;animation-delay:-.8s}.lds-grid div:nth-child(4){top:32px;left:8px;animation-delay:-.4s}.lds-grid div:nth-child(5){top:32px;left:32px;animation-delay:-.8s}.lds-grid div:nth-child(6){top:32px;left:56px;animation-delay:-1.2s}.lds-grid div:nth-child(7){top:56px;left:8px;animation-delay:-.8s}.lds-grid div:nth-child(8){top:56px;left:32px;animation-delay:-1.2s}.lds-grid div:nth-child(9){top:56px;left:56px;animation-delay:-1.6s}@keyframes lds-grid{0%,to{opacity:1}50%{opacity:.5}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: GridLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-grid-loader', template: "<div class=\"lds-grid\">\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n</div>", styles: [".lds-grid{display:inline-block;position:relative;width:80px;height:80px}.lds-grid div{position:absolute;width:16px;height:16px;border-radius:50%;background:var(--iconcolor);animation:lds-grid 1.2s linear infinite}.lds-grid div:nth-child(1){top:8px;left:8px;animation-delay:0s}.lds-grid div:nth-child(2){top:8px;left:32px;animation-delay:-.4s}.lds-grid div:nth-child(3){top:8px;left:56px;animation-delay:-.8s}.lds-grid div:nth-child(4){top:32px;left:8px;animation-delay:-.4s}.lds-grid div:nth-child(5){top:32px;left:32px;animation-delay:-.8s}.lds-grid div:nth-child(6){top:32px;left:56px;animation-delay:-1.2s}.lds-grid div:nth-child(7){top:56px;left:8px;animation-delay:-.8s}.lds-grid div:nth-child(8){top:56px;left:32px;animation-delay:-1.2s}.lds-grid div:nth-child(9){top:56px;left:56px;animation-delay:-1.6s}@keyframes lds-grid{0%,to{opacity:1}50%{opacity:.5}}\n"] }]
        }], ctorParameters: function () { return []; } });

class DualRingLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
DualRingLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: DualRingLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
DualRingLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: DualRingLoaderComponent, selector: "lib-dual-ring-loader", ngImport: i0, template: "<div class=\"lds-dual-ring\"></div>", styles: [".lds-dual-ring{display:inline-block;width:80px;height:80px}.lds-dual-ring:after{content:\" \";display:block;width:64px;height:64px;margin:8px;border-radius:50%;border:6px solid;border-color:var(--iconcolor) transparent var(--iconcolor) transparent;animation:lds-dual-ring 1.2s linear infinite}@keyframes lds-dual-ring{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: DualRingLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-dual-ring-loader', template: "<div class=\"lds-dual-ring\"></div>", styles: [".lds-dual-ring{display:inline-block;width:80px;height:80px}.lds-dual-ring:after{content:\" \";display:block;width:64px;height:64px;margin:8px;border-radius:50%;border:6px solid;border-color:var(--iconcolor) transparent var(--iconcolor) transparent;animation:lds-dual-ring 1.2s linear infinite}@keyframes lds-dual-ring{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class ClockLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
ClockLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: ClockLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ClockLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: ClockLoaderComponent, selector: "lib-clock-loader", ngImport: i0, template: "<div class=\"clock-loader\"></div>", styles: [".clock-loader{--primary-color: var(--iconcolor);--clock-color: var(--primary-color);--clock-width: 4rem;--clock-radius: calc(var(--clock-width) / 2);--clock-minute-length: calc(var(--clock-width) * .4);--clock-hour-length: calc(var(--clock-width) * .2);--clock-thickness: .2rem;position:relative;display:flex;justify-content:center;align-items:center;width:var(--clock-width);height:var(--clock-width);border:3px solid var(--primary-color);border-radius:50%;margin:20px auto}.clock-loader:before,.clock-loader:after{position:absolute;content:\"\";top:calc(var(--clock-radius) * .25);width:var(--clock-thickness);background:var(--primary-color);border-radius:10px;transform-origin:center calc(100% - var(--clock-thickness) / 2);animation:spin infinite linear}.clock-loader:before{height:var(--clock-minute-length);animation-duration:2s}.clock-loader:after{top:calc(var(--clock-radius) * .25 + var(--clock-hour-length));height:var(--clock-hour-length);animation-duration:15s}@keyframes spin{to{transform:rotate(1turn)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: ClockLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-clock-loader', template: "<div class=\"clock-loader\"></div>", styles: [".clock-loader{--primary-color: var(--iconcolor);--clock-color: var(--primary-color);--clock-width: 4rem;--clock-radius: calc(var(--clock-width) / 2);--clock-minute-length: calc(var(--clock-width) * .4);--clock-hour-length: calc(var(--clock-width) * .2);--clock-thickness: .2rem;position:relative;display:flex;justify-content:center;align-items:center;width:var(--clock-width);height:var(--clock-width);border:3px solid var(--primary-color);border-radius:50%;margin:20px auto}.clock-loader:before,.clock-loader:after{position:absolute;content:\"\";top:calc(var(--clock-radius) * .25);width:var(--clock-thickness);background:var(--primary-color);border-radius:10px;transform-origin:center calc(100% - var(--clock-thickness) / 2);animation:spin infinite linear}.clock-loader:before{height:var(--clock-minute-length);animation-duration:2s}.clock-loader:after{top:calc(var(--clock-radius) * .25 + var(--clock-hour-length));height:var(--clock-hour-length);animation-duration:15s}@keyframes spin{to{transform:rotate(1turn)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class DefaultLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
DefaultLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: DefaultLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
DefaultLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: DefaultLoaderComponent, selector: "lib-default-loader", ngImport: i0, template: "<div class=\"lds-default\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-default{display:inline-block;position:relative;width:80px;height:80px}.lds-default div{position:absolute;width:6px;height:6px;background:var(--iconcolor);border-radius:50%;animation:lds-default 1.2s linear infinite}.lds-default div:nth-child(1){animation-delay:0s;top:37px;left:66px}.lds-default div:nth-child(2){animation-delay:-.1s;top:22px;left:62px}.lds-default div:nth-child(3){animation-delay:-.2s;top:11px;left:52px}.lds-default div:nth-child(4){animation-delay:-.3s;top:7px;left:37px}.lds-default div:nth-child(5){animation-delay:-.4s;top:11px;left:22px}.lds-default div:nth-child(6){animation-delay:-.5s;top:22px;left:11px}.lds-default div:nth-child(7){animation-delay:-.6s;top:37px;left:7px}.lds-default div:nth-child(8){animation-delay:-.7s;top:52px;left:11px}.lds-default div:nth-child(9){animation-delay:-.8s;top:62px;left:22px}.lds-default div:nth-child(10){animation-delay:-.9s;top:66px;left:37px}.lds-default div:nth-child(11){animation-delay:-1s;top:62px;left:52px}.lds-default div:nth-child(12){animation-delay:-1.1s;top:52px;left:62px}@keyframes lds-default{0%,20%,80%,to{transform:scale(1)}50%{transform:scale(1.5)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: DefaultLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-default-loader', template: "<div class=\"lds-default\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-default{display:inline-block;position:relative;width:80px;height:80px}.lds-default div{position:absolute;width:6px;height:6px;background:var(--iconcolor);border-radius:50%;animation:lds-default 1.2s linear infinite}.lds-default div:nth-child(1){animation-delay:0s;top:37px;left:66px}.lds-default div:nth-child(2){animation-delay:-.1s;top:22px;left:62px}.lds-default div:nth-child(3){animation-delay:-.2s;top:11px;left:52px}.lds-default div:nth-child(4){animation-delay:-.3s;top:7px;left:37px}.lds-default div:nth-child(5){animation-delay:-.4s;top:11px;left:22px}.lds-default div:nth-child(6){animation-delay:-.5s;top:22px;left:11px}.lds-default div:nth-child(7){animation-delay:-.6s;top:37px;left:7px}.lds-default div:nth-child(8){animation-delay:-.7s;top:52px;left:11px}.lds-default div:nth-child(9){animation-delay:-.8s;top:62px;left:22px}.lds-default div:nth-child(10){animation-delay:-.9s;top:66px;left:37px}.lds-default div:nth-child(11){animation-delay:-1s;top:62px;left:52px}.lds-default div:nth-child(12){animation-delay:-1.1s;top:52px;left:62px}@keyframes lds-default{0%,20%,80%,to{transform:scale(1)}50%{transform:scale(1.5)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class EllipsisLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
EllipsisLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: EllipsisLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
EllipsisLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: EllipsisLoaderComponent, selector: "lib-ellipsis-loader", ngImport: i0, template: "<div class=\"lds-ellipsis\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-ellipsis{display:inline-block;position:relative;width:80px;height:80px}.lds-ellipsis div{position:absolute;top:33px;width:13px;height:13px;border-radius:50%;background:var(--iconcolor);animation-timing-function:cubic-bezier(0,1,1,0)}.lds-ellipsis div:nth-child(1){left:8px;animation:lds-ellipsis1 .6s infinite}.lds-ellipsis div:nth-child(2){left:8px;animation:lds-ellipsis2 .6s infinite}.lds-ellipsis div:nth-child(3){left:32px;animation:lds-ellipsis2 .6s infinite}.lds-ellipsis div:nth-child(4){left:56px;animation:lds-ellipsis3 .6s infinite}@keyframes lds-ellipsis1{0%{transform:scale(0)}to{transform:scale(1)}}@keyframes lds-ellipsis3{0%{transform:scale(1)}to{transform:scale(0)}}@keyframes lds-ellipsis2{0%{transform:translate(0)}to{transform:translate(24px)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: EllipsisLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ellipsis-loader', template: "<div class=\"lds-ellipsis\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-ellipsis{display:inline-block;position:relative;width:80px;height:80px}.lds-ellipsis div{position:absolute;top:33px;width:13px;height:13px;border-radius:50%;background:var(--iconcolor);animation-timing-function:cubic-bezier(0,1,1,0)}.lds-ellipsis div:nth-child(1){left:8px;animation:lds-ellipsis1 .6s infinite}.lds-ellipsis div:nth-child(2){left:8px;animation:lds-ellipsis2 .6s infinite}.lds-ellipsis div:nth-child(3){left:32px;animation:lds-ellipsis2 .6s infinite}.lds-ellipsis div:nth-child(4){left:56px;animation:lds-ellipsis3 .6s infinite}@keyframes lds-ellipsis1{0%{transform:scale(0)}to{transform:scale(1)}}@keyframes lds-ellipsis3{0%{transform:scale(1)}to{transform:scale(0)}}@keyframes lds-ellipsis2{0%{transform:translate(0)}to{transform:translate(24px)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class SpinnerLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
SpinnerLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: SpinnerLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
SpinnerLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: SpinnerLoaderComponent, selector: "lib-spinner-loader", ngImport: i0, template: "<div class=\"lds-spinner\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-spinner{color:official;display:inline-block;position:relative;width:80px;height:80px}.lds-spinner div{transform-origin:40px 40px;animation:lds-spinner 1.2s linear infinite}.lds-spinner div:after{content:\" \";display:block;position:absolute;top:3px;left:37px;width:6px;height:18px;border-radius:20%;background:var(--iconcolor)}.lds-spinner div:nth-child(1){transform:rotate(0);animation-delay:-1.1s}.lds-spinner div:nth-child(2){transform:rotate(30deg);animation-delay:-1s}.lds-spinner div:nth-child(3){transform:rotate(60deg);animation-delay:-.9s}.lds-spinner div:nth-child(4){transform:rotate(90deg);animation-delay:-.8s}.lds-spinner div:nth-child(5){transform:rotate(120deg);animation-delay:-.7s}.lds-spinner div:nth-child(6){transform:rotate(150deg);animation-delay:-.6s}.lds-spinner div:nth-child(7){transform:rotate(180deg);animation-delay:-.5s}.lds-spinner div:nth-child(8){transform:rotate(210deg);animation-delay:-.4s}.lds-spinner div:nth-child(9){transform:rotate(240deg);animation-delay:-.3s}.lds-spinner div:nth-child(10){transform:rotate(270deg);animation-delay:-.2s}.lds-spinner div:nth-child(11){transform:rotate(300deg);animation-delay:-.1s}.lds-spinner div:nth-child(12){transform:rotate(330deg);animation-delay:0s}@keyframes lds-spinner{0%{opacity:1}to{opacity:0}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: SpinnerLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-spinner-loader', template: "<div class=\"lds-spinner\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-spinner{color:official;display:inline-block;position:relative;width:80px;height:80px}.lds-spinner div{transform-origin:40px 40px;animation:lds-spinner 1.2s linear infinite}.lds-spinner div:after{content:\" \";display:block;position:absolute;top:3px;left:37px;width:6px;height:18px;border-radius:20%;background:var(--iconcolor)}.lds-spinner div:nth-child(1){transform:rotate(0);animation-delay:-1.1s}.lds-spinner div:nth-child(2){transform:rotate(30deg);animation-delay:-1s}.lds-spinner div:nth-child(3){transform:rotate(60deg);animation-delay:-.9s}.lds-spinner div:nth-child(4){transform:rotate(90deg);animation-delay:-.8s}.lds-spinner div:nth-child(5){transform:rotate(120deg);animation-delay:-.7s}.lds-spinner div:nth-child(6){transform:rotate(150deg);animation-delay:-.6s}.lds-spinner div:nth-child(7){transform:rotate(180deg);animation-delay:-.5s}.lds-spinner div:nth-child(8){transform:rotate(210deg);animation-delay:-.4s}.lds-spinner div:nth-child(9){transform:rotate(240deg);animation-delay:-.3s}.lds-spinner div:nth-child(10){transform:rotate(270deg);animation-delay:-.2s}.lds-spinner div:nth-child(11){transform:rotate(300deg);animation-delay:-.1s}.lds-spinner div:nth-child(12){transform:rotate(330deg);animation-delay:0s}@keyframes lds-spinner{0%{opacity:1}to{opacity:0}}\n"] }]
        }], ctorParameters: function () { return []; } });

class FacebookLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
FacebookLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: FacebookLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
FacebookLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: FacebookLoaderComponent, selector: "lib-facebook-loader", ngImport: i0, template: "<div class=\"lds-facebook\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-facebook{display:inline-block;position:relative;width:80px;height:80px}.lds-facebook div{display:inline-block;position:absolute;left:8px;width:16px;background:var(--iconcolor);animation:lds-facebook 1.2s cubic-bezier(0,.5,.5,1) infinite}.lds-facebook div:nth-child(1){left:8px;animation-delay:-.24s}.lds-facebook div:nth-child(2){left:32px;animation-delay:-.12s}.lds-facebook div:nth-child(3){left:56px;animation-delay:0}@keyframes lds-facebook{0%{top:8px;height:64px}50%,to{top:24px;height:32px}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: FacebookLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-facebook-loader', template: "<div class=\"lds-facebook\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-facebook{display:inline-block;position:relative;width:80px;height:80px}.lds-facebook div{display:inline-block;position:absolute;left:8px;width:16px;background:var(--iconcolor);animation:lds-facebook 1.2s cubic-bezier(0,.5,.5,1) infinite}.lds-facebook div:nth-child(1){left:8px;animation-delay:-.24s}.lds-facebook div:nth-child(2){left:32px;animation-delay:-.12s}.lds-facebook div:nth-child(3){left:56px;animation-delay:0}@keyframes lds-facebook{0%{top:8px;height:64px}50%,to{top:24px;height:32px}}\n"] }]
        }], ctorParameters: function () { return []; } });

class HeartLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
HeartLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: HeartLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
HeartLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: HeartLoaderComponent, selector: "lib-heart-loader", ngImport: i0, template: "<div class=\"lds-heart\">\r\n    <div></div>\r\n</div>", styles: [".lds-heart{display:inline-block;position:relative;width:80px;height:80px;transform:rotate(45deg);transform-origin:40px 40px}.lds-heart div{top:32px;left:32px;position:absolute;width:32px;height:32px;background:var(--iconcolor);animation:lds-heart 1.2s infinite cubic-bezier(.215,.61,.355,1)}.lds-heart div:after,.lds-heart div:before{content:\" \";position:absolute;display:block;width:32px;height:32px;background:var(--iconcolor)}.lds-heart div:before{left:-24px;border-radius:50% 0 0 50%}.lds-heart div:after{top:-24px;border-radius:50% 50% 0 0}@keyframes lds-heart{0%{transform:scale(.95)}5%{transform:scale(1.1)}39%{transform:scale(.85)}45%{transform:scale(1)}60%{transform:scale(.95)}to{transform:scale(.9)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: HeartLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-heart-loader', template: "<div class=\"lds-heart\">\r\n    <div></div>\r\n</div>", styles: [".lds-heart{display:inline-block;position:relative;width:80px;height:80px;transform:rotate(45deg);transform-origin:40px 40px}.lds-heart div{top:32px;left:32px;position:absolute;width:32px;height:32px;background:var(--iconcolor);animation:lds-heart 1.2s infinite cubic-bezier(.215,.61,.355,1)}.lds-heart div:after,.lds-heart div:before{content:\" \";position:absolute;display:block;width:32px;height:32px;background:var(--iconcolor)}.lds-heart div:before{left:-24px;border-radius:50% 0 0 50%}.lds-heart div:after{top:-24px;border-radius:50% 50% 0 0}@keyframes lds-heart{0%{transform:scale(.95)}5%{transform:scale(1.1)}39%{transform:scale(.85)}45%{transform:scale(1)}60%{transform:scale(.95)}to{transform:scale(.9)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class HourglassLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
HourglassLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: HourglassLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
HourglassLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: HourglassLoaderComponent, selector: "lib-hourglass-loader", ngImport: i0, template: "<div class=\"lds-hourglass\"></div>", styles: [".lds-hourglass{display:inline-block;position:relative;width:80px;height:80px}.lds-hourglass:after{content:\" \";display:block;border-radius:50%;width:0;height:0;margin:8px;box-sizing:border-box;border:32px solid var(--iconcolor);border-color:var(--iconcolor) transparent var(--iconcolor) transparent;animation:lds-hourglass 1.2s infinite}@keyframes lds-hourglass{0%{transform:rotate(0);animation-timing-function:cubic-bezier(.55,.055,.675,.19)}50%{transform:rotate(900deg);animation-timing-function:cubic-bezier(.215,.61,.355,1)}to{transform:rotate(1800deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: HourglassLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-hourglass-loader', template: "<div class=\"lds-hourglass\"></div>", styles: [".lds-hourglass{display:inline-block;position:relative;width:80px;height:80px}.lds-hourglass:after{content:\" \";display:block;border-radius:50%;width:0;height:0;margin:8px;box-sizing:border-box;border:32px solid var(--iconcolor);border-color:var(--iconcolor) transparent var(--iconcolor) transparent;animation:lds-hourglass 1.2s infinite}@keyframes lds-hourglass{0%{transform:rotate(0);animation-timing-function:cubic-bezier(.55,.055,.675,.19)}50%{transform:rotate(900deg);animation-timing-function:cubic-bezier(.215,.61,.355,1)}to{transform:rotate(1800deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class RingLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RingLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RingLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
RingLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: RingLoaderComponent, selector: "lib-ring-loader", ngImport: i0, template: "<div class=\"lds-ring\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-ring{display:inline-block;position:relative;width:80px;height:80px}.lds-ring div{box-sizing:border-box;display:block;position:absolute;width:64px;height:64px;margin:8px;border:8px solid;border-radius:50%;animation:lds-ring 1.2s cubic-bezier(.5,0,.5,1) infinite;border-color:var(--iconcolor) transparent transparent transparent}.lds-ring div:nth-child(1){animation-delay:-.45s}.lds-ring div:nth-child(2){animation-delay:-.3s}.lds-ring div:nth-child(3){animation-delay:-.15s}@keyframes lds-ring{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RingLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ring-loader', template: "<div class=\"lds-ring\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-ring{display:inline-block;position:relative;width:80px;height:80px}.lds-ring div{box-sizing:border-box;display:block;position:absolute;width:64px;height:64px;margin:8px;border:8px solid;border-radius:50%;animation:lds-ring 1.2s cubic-bezier(.5,0,.5,1) infinite;border-color:var(--iconcolor) transparent transparent transparent}.lds-ring div:nth-child(1){animation-delay:-.45s}.lds-ring div:nth-child(2){animation-delay:-.3s}.lds-ring div:nth-child(3){animation-delay:-.15s}@keyframes lds-ring{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class RippleLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RippleLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RippleLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
RippleLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: RippleLoaderComponent, selector: "lib-ripple-loader", ngImport: i0, template: "<div class=\"lds-ripple\"><div></div><div></div></div>", styles: [".lds-ripple{display:inline-block;position:relative;width:80px;height:80px}.lds-ripple div{position:absolute;border:4px solid var(--iconcolor);opacity:1;border-radius:50%;animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite}.lds-ripple div:nth-child(2){animation-delay:-.5s}@keyframes lds-ripple{0%{top:36px;left:36px;width:0;height:0;opacity:1}to{top:0px;left:0px;width:72px;height:72px;opacity:0}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RippleLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-ripple-loader', template: "<div class=\"lds-ripple\"><div></div><div></div></div>", styles: [".lds-ripple{display:inline-block;position:relative;width:80px;height:80px}.lds-ripple div{position:absolute;border:4px solid var(--iconcolor);opacity:1;border-radius:50%;animation:lds-ripple 1s cubic-bezier(0,.2,.8,1) infinite}.lds-ripple div:nth-child(2){animation-delay:-.5s}@keyframes lds-ripple{0%{top:36px;left:36px;width:0;height:0;opacity:1}to{top:0px;left:0px;width:72px;height:72px;opacity:0}}\n"] }]
        }], ctorParameters: function () { return []; } });

class RollerLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
RollerLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RollerLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
RollerLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: RollerLoaderComponent, selector: "lib-roller-loader", ngImport: i0, template: "<div class=\"lds-roller\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-roller{display:inline-block;position:relative;width:80px;height:80px}.lds-roller div{animation:lds-roller 1.2s cubic-bezier(.5,0,.5,1) infinite;transform-origin:40px 40px}.lds-roller div:after{content:\" \";display:block;position:absolute;width:7px;height:7px;border-radius:50%;background:var(--iconcolor);margin:-4px 0 0 -4px}.lds-roller div:nth-child(1){animation-delay:-36ms}.lds-roller div:nth-child(1):after{top:63px;left:63px}.lds-roller div:nth-child(2){animation-delay:-72ms}.lds-roller div:nth-child(2):after{top:68px;left:56px}.lds-roller div:nth-child(3){animation-delay:-.108s}.lds-roller div:nth-child(3):after{top:71px;left:48px}.lds-roller div:nth-child(4){animation-delay:-.144s}.lds-roller div:nth-child(4):after{top:72px;left:40px}.lds-roller div:nth-child(5){animation-delay:-.18s}.lds-roller div:nth-child(5):after{top:71px;left:32px}.lds-roller div:nth-child(6){animation-delay:-.216s}.lds-roller div:nth-child(6):after{top:68px;left:24px}.lds-roller div:nth-child(7){animation-delay:-.252s}.lds-roller div:nth-child(7):after{top:63px;left:17px}.lds-roller div:nth-child(8){animation-delay:-.288s}.lds-roller div:nth-child(8):after{top:56px;left:12px}@keyframes lds-roller{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RollerLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-roller-loader', template: "<div class=\"lds-roller\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>", styles: [".lds-roller{display:inline-block;position:relative;width:80px;height:80px}.lds-roller div{animation:lds-roller 1.2s cubic-bezier(.5,0,.5,1) infinite;transform-origin:40px 40px}.lds-roller div:after{content:\" \";display:block;position:absolute;width:7px;height:7px;border-radius:50%;background:var(--iconcolor);margin:-4px 0 0 -4px}.lds-roller div:nth-child(1){animation-delay:-36ms}.lds-roller div:nth-child(1):after{top:63px;left:63px}.lds-roller div:nth-child(2){animation-delay:-72ms}.lds-roller div:nth-child(2):after{top:68px;left:56px}.lds-roller div:nth-child(3){animation-delay:-.108s}.lds-roller div:nth-child(3):after{top:71px;left:48px}.lds-roller div:nth-child(4){animation-delay:-.144s}.lds-roller div:nth-child(4):after{top:72px;left:40px}.lds-roller div:nth-child(5){animation-delay:-.18s}.lds-roller div:nth-child(5):after{top:71px;left:32px}.lds-roller div:nth-child(6){animation-delay:-.216s}.lds-roller div:nth-child(6):after{top:68px;left:24px}.lds-roller div:nth-child(7){animation-delay:-.252s}.lds-roller div:nth-child(7):after{top:63px;left:17px}.lds-roller div:nth-child(8){animation-delay:-.288s}.lds-roller div:nth-child(8):after{top:56px;left:12px}@keyframes lds-roller{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class WaterWaveLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
WaterWaveLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: WaterWaveLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
WaterWaveLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: WaterWaveLoaderComponent, selector: "lib-water-wave-loader", ngImport: i0, template: "<div class=\"water\"></div>", styles: [".water{width:100px;height:100px;background-color:var(--iconcolor);border-radius:50%;position:relative;box-shadow:inset 0 0 30px #00000080,0 4px 10px #00000080;overflow:hidden;margin:20px auto}.water:before,.water:after{content:\"\";position:absolute;width:400px;height:600px;top:-100px;background-color:#fff}.water:before{border-radius:45%;background:rgba(255,255,255,.7);animation:wave 5s linear infinite}.water:after{border-radius:35%;background:rgba(255,255,255,.3);animation:wave 5s linear infinite}@keyframes wave{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: WaterWaveLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-water-wave-loader', template: "<div class=\"water\"></div>", styles: [".water{width:100px;height:100px;background-color:var(--iconcolor);border-radius:50%;position:relative;box-shadow:inset 0 0 30px #00000080,0 4px 10px #00000080;overflow:hidden;margin:20px auto}.water:before,.water:after{content:\"\";position:absolute;width:400px;height:600px;top:-100px;background-color:#fff}.water:before{border-radius:45%;background:rgba(255,255,255,.7);animation:wave 5s linear infinite}.water:after{border-radius:35%;background:rgba(255,255,255,.3);animation:wave 5s linear infinite}@keyframes wave{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class MulticircleLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
MulticircleLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: MulticircleLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
MulticircleLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: MulticircleLoaderComponent, selector: "lib-multicircle-loader", ngImport: i0, template: "<div id=\"loader\"></div>", styles: ["#loader{display:block;position:relative;left:50%;top:50%;width:150px;height:150px;margin:-75px 0 0 -75px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);animation:spin 2s linear infinite}#loader:before{content:\"\";position:absolute;top:5px;left:5px;right:5px;bottom:5px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.2;animation:spin 3s linear infinite}#loader:after{content:\"\";position:absolute;top:15px;left:15px;right:15px;bottom:15px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.6;animation:spin 1.5s linear infinite}@keyframes spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: MulticircleLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-multicircle-loader', template: "<div id=\"loader\"></div>", styles: ["#loader{display:block;position:relative;left:50%;top:50%;width:150px;height:150px;margin:-75px 0 0 -75px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);animation:spin 2s linear infinite}#loader:before{content:\"\";position:absolute;top:5px;left:5px;right:5px;bottom:5px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.2;animation:spin 3s linear infinite}#loader:after{content:\"\";position:absolute;top:15px;left:15px;right:15px;bottom:15px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.6;animation:spin 1.5s linear infinite}@keyframes spin{0%{transform:rotate(0)}to{transform:rotate(360deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class ThreeBounceLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
ThreeBounceLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: ThreeBounceLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
ThreeBounceLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: ThreeBounceLoaderComponent, selector: "lib-three-bounce-loader", ngImport: i0, template: "<div class=\"wrapper\">\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n</div>", styles: [".wrapper{width:200px;height:60px;position:absolute;left:50%;top:40%;transform:translate(-50%,-50%)}.circle{width:20px;height:20px;position:absolute;border-radius:50%;background-color:var(--iconcolor);left:15%;transform-origin:50%;animation:circle .5s alternate infinite ease}@keyframes circle{0%{top:60px;height:5px;border-radius:50px 50px 25px 25px;transform:scaleX(1.7)}40%{height:20px;border-radius:50%;transform:scaleX(1)}to{top:0%}}.circle:nth-child(2){left:45%;animation-delay:.2s}.circle:nth-child(3){left:auto;right:15%;animation-delay:.3s}.shadow{width:20px;height:4px;border-radius:50%;background-color:#00000080;position:absolute;top:62px;transform-origin:50%;z-index:-1;left:15%;filter:blur(1px);animation:shadow .5s alternate infinite ease}@keyframes shadow{0%{transform:scaleX(1.5)}40%{transform:scaleX(1);opacity:.7}to{transform:scaleX(.2);opacity:.4}}.shadow:nth-child(4){left:45%;animation-delay:.2s}.shadow:nth-child(5){left:auto;right:15%;animation-delay:.3s}.wrapper span{position:absolute;top:75px;font-family:Lato;font-size:20px;letter-spacing:12px;color:var(--iconcolor);left:15%}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: ThreeBounceLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-three-bounce-loader', template: "<div class=\"wrapper\">\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n</div>", styles: [".wrapper{width:200px;height:60px;position:absolute;left:50%;top:40%;transform:translate(-50%,-50%)}.circle{width:20px;height:20px;position:absolute;border-radius:50%;background-color:var(--iconcolor);left:15%;transform-origin:50%;animation:circle .5s alternate infinite ease}@keyframes circle{0%{top:60px;height:5px;border-radius:50px 50px 25px 25px;transform:scaleX(1.7)}40%{height:20px;border-radius:50%;transform:scaleX(1)}to{top:0%}}.circle:nth-child(2){left:45%;animation-delay:.2s}.circle:nth-child(3){left:auto;right:15%;animation-delay:.3s}.shadow{width:20px;height:4px;border-radius:50%;background-color:#00000080;position:absolute;top:62px;transform-origin:50%;z-index:-1;left:15%;filter:blur(1px);animation:shadow .5s alternate infinite ease}@keyframes shadow{0%{transform:scaleX(1.5)}40%{transform:scaleX(1);opacity:.7}to{transform:scaleX(.2);opacity:.4}}.shadow:nth-child(4){left:45%;animation-delay:.2s}.shadow:nth-child(5){left:auto;right:15%;animation-delay:.3s}.wrapper span{position:absolute;top:75px;font-family:Lato;font-size:20px;letter-spacing:12px;color:var(--iconcolor);left:15%}\n"] }]
        }], ctorParameters: function () { return []; } });

class JellyboxLoaderComponent {
    constructor() { }
    ngOnInit() {
    }
}
JellyboxLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: JellyboxLoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
JellyboxLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: JellyboxLoaderComponent, selector: "lib-jellybox-loader", ngImport: i0, template: "<div id=\"loader\">\n    <div id=\"box\"></div>\n    <div id=\"shadow\"></div>\n  </div>", styles: ["@keyframes loader{0%{left:-100px}to{left:110%}}#box{width:70px;height:70px;background:var(--iconcolor);animation:animate .5s linear infinite;border-radius:3px;margin:10px auto}@keyframes animate{17%{border-bottom-right-radius:3px}25%{transform:translateY(9px) rotate(22.5deg)}50%{transform:translateY(18px) scaleY(.9) rotate(45deg);border-bottom-right-radius:40px}75%{transform:translateY(9px) rotate(67.5deg)}to{transform:translateY(0) rotate(90deg)}}#shadow{width:80px;height:5px;background:#000;opacity:.1;border-radius:50%;animation:shadow .5s linear infinite;margin:0 auto}@keyframes shadow{50%{transform:scaleX(1.2)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: JellyboxLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-jellybox-loader', template: "<div id=\"loader\">\n    <div id=\"box\"></div>\n    <div id=\"shadow\"></div>\n  </div>", styles: ["@keyframes loader{0%{left:-100px}to{left:110%}}#box{width:70px;height:70px;background:var(--iconcolor);animation:animate .5s linear infinite;border-radius:3px;margin:10px auto}@keyframes animate{17%{border-bottom-right-radius:3px}25%{transform:translateY(9px) rotate(22.5deg)}50%{transform:translateY(18px) scaleY(.9) rotate(45deg);border-bottom-right-radius:40px}75%{transform:translateY(9px) rotate(67.5deg)}to{transform:translateY(0) rotate(90deg)}}#shadow{width:80px;height:5px;background:#000;opacity:.1;border-radius:50%;animation:shadow .5s linear infinite;margin:0 auto}@keyframes shadow{50%{transform:scaleX(1.2)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class RotatingPlaneComponent {
    constructor() { }
    ngOnInit() {
    }
}
RotatingPlaneComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RotatingPlaneComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
RotatingPlaneComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: RotatingPlaneComponent, selector: "lib-rotating-plane", ngImport: i0, template: "<div class=\"rotating-plane\"></div>", styles: [".rotating-plane{width:40px;height:40px;background-color:var(--iconcolor);margin:0 auto;animation:rotateplane 1.2s infinite ease-in-out}@keyframes rotateplane{0%{transform:perspective(120px) rotateX(0) rotateY(0);-webkit-transform:perspective(120px) rotateX(0deg) rotateY(0deg)}50%{transform:perspective(120px) rotateX(-180.1deg) rotateY(0);-webkit-transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg)}to{transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg);-webkit-transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg)}}\n"] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: RotatingPlaneComponent, decorators: [{
            type: Component,
            args: [{ selector: 'lib-rotating-plane', template: "<div class=\"rotating-plane\"></div>", styles: [".rotating-plane{width:40px;height:40px;background-color:var(--iconcolor);margin:0 auto;animation:rotateplane 1.2s infinite ease-in-out}@keyframes rotateplane{0%{transform:perspective(120px) rotateX(0) rotateY(0);-webkit-transform:perspective(120px) rotateX(0deg) rotateY(0deg)}50%{transform:perspective(120px) rotateX(-180.1deg) rotateY(0);-webkit-transform:perspective(120px) rotateX(-180.1deg) rotateY(0deg)}to{transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg);-webkit-transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg)}}\n"] }]
        }], ctorParameters: function () { return []; } });

class NgxHttpLoaderComponent {
    constructor(requestService, service, sanitizer) {
        this.requestService = requestService;
        this.service = service;
        this.sanitizer = sanitizer;
        this.customEnumLoader = NgxLoader;
        this.loader = NgxLoader.RIPPLE;
        this.filterUrlRegexPatterns = [];
        this.filterUrls = [];
        this.filterHttpHeaders = [];
        this.filterHttpMethods = [];
        this.delay = 0;
        this.extraDelay = 0;
        this.minDuration = 0;
        this.opacity = 0.8;
        // @Input() public backdropBackgroundColor = 'linear-gradient(45deg, #222428, #444856)';
        // @Input() public backdropBackgroundColor = 'transperent';
        this.backdropBackgroundColor = 'linear-gradient(0deg, black, transparent);';
        this.iconColor = 'white';
        this.title = '';
        this.titleColor = '#fff';
        this.titleSize = '3rem';
        this.subTitle = '';
        this.subTitleColor = '#6c757d';
        this.subTitleSize = '1.2rem';
        this.custom = false;
        this.showuntil = Date.now();
    }
    ngOnChanges(changes) {
        if (this.filterUrlRegexPatterns.length > 0 || this.filterUrls.length > 0
            || this.filterHttpHeaders.length > 0 || this.filterHttpMethods.length > 0)
            this.initAllFilters();
    }
    ngOnInit() {
        this.initAllFilters();
    }
    initAllFilters() {
        this.requestService.setUrlPatterns = this.filterUrlRegexPatterns;
        this.requestService.setFilterUrls = this.filterUrls;
        this.requestService.setFilterMethods = this.filterHttpMethods;
        this.requestService.setFilterHeaders = this.filterHttpHeaders;
        this.initShowObservable();
    }
    initShowObservable() {
        const [show, hide] = partition(($hide) => $hide)(this.requestService.reqStatus);
        this.show$ = merge(this.requestService.reqStatus.pipe(switchMap(() => show.pipe(debounce(() => timer(this.delay))))), show.pipe(switchMap(() => hide.pipe(debounce(() => this.showUpto())))), this.service.isShowLoader).pipe(distinctUntilChanged(), tap(x => this.updateHideDelay(x)));
    }
    updateHideDelay(bool) {
        if (bool)
            this.showuntil = Date.now() + this.minDuration;
    }
    showUpto() {
        return timer(Math.max(this.extraDelay, this.showuntil - Date.now()));
    }
}
NgxHttpLoaderComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderComponent, deps: [{ token: NgxHttpLoaderInterceptor }, { token: NgxHttpLoaderService }, { token: i3.DomSanitizer }], target: i0.ɵɵFactoryTarget.Component });
NgxHttpLoaderComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "12.0.0", version: "13.3.10", type: NgxHttpLoaderComponent, selector: "ngx-http-loader", inputs: { customTemplate: "customTemplate", customLoader: "customLoader", loader: "loader", filterUrlRegexPatterns: "filterUrlRegexPatterns", filterUrls: "filterUrls", filterHttpHeaders: "filterHttpHeaders", filterHttpMethods: "filterHttpMethods", delay: "delay", extraDelay: "extraDelay", minDuration: "minDuration", opacity: "opacity", backdropBackgroundColor: "backdropBackgroundColor", iconColor: "iconColor", title: "title", titleColor: "titleColor", titleSize: "titleSize", subTitle: "subTitle", subTitleColor: "subTitleColor", subTitleSize: "subTitleSize", custom: "custom" }, usesOnChanges: true, ngImport: i0, template: "<div *ngIf=\"show$ | async\">\r\n    <ng-template [ngTemplateOutlet]=\"customTemplate || defaultTemplate\"></ng-template>\r\n    <ng-template #defaultTemplate>\r\n        <div class=\"custom-loader vertical-center\"\r\n            [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--background-color: ' + backdropBackgroundColor + '; opacity :' + opacity)\">\r\n            <div class=\"custom-loader-section text-light\"\r\n                [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--iconcolor: ' + iconColor)\">\r\n                <ng-container *ngIf=\"custom\">\r\n                    <ng-template [ngTemplateOutlet]=\"customLoader\"></ng-template>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"!custom\">\r\n                    <lib-gear-loader *ngIf=\"loader === customEnumLoader.GEAR\"></lib-gear-loader>\r\n                    <lib-grid-loader *ngIf=\"loader === customEnumLoader.GRID\"></lib-grid-loader>\r\n                    <lib-dual-ring-loader *ngIf=\"loader === customEnumLoader.DUALRING\"></lib-dual-ring-loader>\r\n                    <lib-clock-loader *ngIf=\"loader === customEnumLoader.CLOCK\"></lib-clock-loader>\r\n                    <lib-default-loader *ngIf=\"loader === customEnumLoader.DEFAULT\"></lib-default-loader>\r\n                    <lib-ellipsis-loader *ngIf=\"loader === customEnumLoader.ELLIPSIS\"></lib-ellipsis-loader>\r\n                    <lib-spinner-loader *ngIf=\"loader === customEnumLoader.SPINNER\"></lib-spinner-loader>\r\n                    <lib-facebook-loader *ngIf=\"loader === customEnumLoader.FACEBOOK\"></lib-facebook-loader>\r\n                    <lib-heart-loader *ngIf=\"loader === customEnumLoader.HEART\"></lib-heart-loader>\r\n                    <lib-hourglass-loader *ngIf=\"loader === customEnumLoader.HOURGLASS\"></lib-hourglass-loader>\r\n                    <lib-ring-loader *ngIf=\"loader === customEnumLoader.RING\"></lib-ring-loader>\r\n                    <lib-ripple-loader *ngIf=\"loader === customEnumLoader.RIPPLE\"></lib-ripple-loader>\r\n                    <lib-roller-loader *ngIf=\"loader === customEnumLoader.ROLLER\"></lib-roller-loader>\r\n                    <lib-water-wave-loader *ngIf=\"loader === customEnumLoader.WATERWAVE\"></lib-water-wave-loader>\r\n                    <lib-multicircle-loader *ngIf=\"loader === customEnumLoader.MULTICIRCLE\"></lib-multicircle-loader>\r\n                    <lib-three-bounce-loader *ngIf=\"loader === customEnumLoader.THREEBOUNCE\"></lib-three-bounce-loader>\r\n                    <lib-jellybox-loader *ngIf=\"loader === customEnumLoader.JELLYBOX\"></lib-jellybox-loader>\r\n                    <lib-rotating-plane *ngIf=\"loader === customEnumLoader.ROTATINGPLANE\"></lib-rotating-plane>\r\n                </ng-container>\r\n                <h1 *ngIf=\"title\" class=\"font-weight-bold text-shadow\"\r\n                    style=\"font-family:Trebuchet MS,Helvetica,sans-serif; width: 50%; margin: 10px auto; margin-top: 20px; word-break: break-all;\"\r\n                    [style.color]=\"titleColor\" [style.fontSize]=\"titleSize\">\r\n                    {{title}}\r\n                </h1>\r\n                <div style=\"width: 50%; margin: 10px auto; word-break: break-all;\" *ngIf=\"subTitle\"\r\n                    [style.color]=\"subTitleColor\" [style.fontSize]=\"subTitleSize\">{{subTitle}}</div>\r\n            </div>\r\n        </div>\r\n    </ng-template>\r\n</div>", styles: [".custom-loader{position:fixed;top:0;left:0;width:100%;height:100%;background:var(--background-color);color:#fff;z-index:99999;transition:all .3s linear}.custom-loader .custom-loader-section{text-align:center;width:100%;color:#f8f9fa}.custom-loader ::ng-deep>*{vertical-align:middle;white-space:normal;display:inline-block;z-index:99999999999}.vertical-center:before{content:\"\";display:inline-block;vertical-align:middle;width:0;height:100%}\n"], components: [{ type: GearLoaderComponent, selector: "lib-gear-loader" }, { type: GridLoaderComponent, selector: "lib-grid-loader" }, { type: DualRingLoaderComponent, selector: "lib-dual-ring-loader" }, { type: ClockLoaderComponent, selector: "lib-clock-loader" }, { type: DefaultLoaderComponent, selector: "lib-default-loader" }, { type: EllipsisLoaderComponent, selector: "lib-ellipsis-loader" }, { type: SpinnerLoaderComponent, selector: "lib-spinner-loader" }, { type: FacebookLoaderComponent, selector: "lib-facebook-loader" }, { type: HeartLoaderComponent, selector: "lib-heart-loader" }, { type: HourglassLoaderComponent, selector: "lib-hourglass-loader" }, { type: RingLoaderComponent, selector: "lib-ring-loader" }, { type: RippleLoaderComponent, selector: "lib-ripple-loader" }, { type: RollerLoaderComponent, selector: "lib-roller-loader" }, { type: WaterWaveLoaderComponent, selector: "lib-water-wave-loader" }, { type: MulticircleLoaderComponent, selector: "lib-multicircle-loader" }, { type: ThreeBounceLoaderComponent, selector: "lib-three-bounce-loader" }, { type: JellyboxLoaderComponent, selector: "lib-jellybox-loader" }, { type: RotatingPlaneComponent, selector: "lib-rotating-plane" }], directives: [{ type: i22.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { type: i22.NgTemplateOutlet, selector: "[ngTemplateOutlet]", inputs: ["ngTemplateOutletContext", "ngTemplateOutlet"] }], pipes: { "async": i22.AsyncPipe } });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderComponent, decorators: [{
            type: Component,
            args: [{ selector: 'ngx-http-loader', template: "<div *ngIf=\"show$ | async\">\r\n    <ng-template [ngTemplateOutlet]=\"customTemplate || defaultTemplate\"></ng-template>\r\n    <ng-template #defaultTemplate>\r\n        <div class=\"custom-loader vertical-center\"\r\n            [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--background-color: ' + backdropBackgroundColor + '; opacity :' + opacity)\">\r\n            <div class=\"custom-loader-section text-light\"\r\n                [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--iconcolor: ' + iconColor)\">\r\n                <ng-container *ngIf=\"custom\">\r\n                    <ng-template [ngTemplateOutlet]=\"customLoader\"></ng-template>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"!custom\">\r\n                    <lib-gear-loader *ngIf=\"loader === customEnumLoader.GEAR\"></lib-gear-loader>\r\n                    <lib-grid-loader *ngIf=\"loader === customEnumLoader.GRID\"></lib-grid-loader>\r\n                    <lib-dual-ring-loader *ngIf=\"loader === customEnumLoader.DUALRING\"></lib-dual-ring-loader>\r\n                    <lib-clock-loader *ngIf=\"loader === customEnumLoader.CLOCK\"></lib-clock-loader>\r\n                    <lib-default-loader *ngIf=\"loader === customEnumLoader.DEFAULT\"></lib-default-loader>\r\n                    <lib-ellipsis-loader *ngIf=\"loader === customEnumLoader.ELLIPSIS\"></lib-ellipsis-loader>\r\n                    <lib-spinner-loader *ngIf=\"loader === customEnumLoader.SPINNER\"></lib-spinner-loader>\r\n                    <lib-facebook-loader *ngIf=\"loader === customEnumLoader.FACEBOOK\"></lib-facebook-loader>\r\n                    <lib-heart-loader *ngIf=\"loader === customEnumLoader.HEART\"></lib-heart-loader>\r\n                    <lib-hourglass-loader *ngIf=\"loader === customEnumLoader.HOURGLASS\"></lib-hourglass-loader>\r\n                    <lib-ring-loader *ngIf=\"loader === customEnumLoader.RING\"></lib-ring-loader>\r\n                    <lib-ripple-loader *ngIf=\"loader === customEnumLoader.RIPPLE\"></lib-ripple-loader>\r\n                    <lib-roller-loader *ngIf=\"loader === customEnumLoader.ROLLER\"></lib-roller-loader>\r\n                    <lib-water-wave-loader *ngIf=\"loader === customEnumLoader.WATERWAVE\"></lib-water-wave-loader>\r\n                    <lib-multicircle-loader *ngIf=\"loader === customEnumLoader.MULTICIRCLE\"></lib-multicircle-loader>\r\n                    <lib-three-bounce-loader *ngIf=\"loader === customEnumLoader.THREEBOUNCE\"></lib-three-bounce-loader>\r\n                    <lib-jellybox-loader *ngIf=\"loader === customEnumLoader.JELLYBOX\"></lib-jellybox-loader>\r\n                    <lib-rotating-plane *ngIf=\"loader === customEnumLoader.ROTATINGPLANE\"></lib-rotating-plane>\r\n                </ng-container>\r\n                <h1 *ngIf=\"title\" class=\"font-weight-bold text-shadow\"\r\n                    style=\"font-family:Trebuchet MS,Helvetica,sans-serif; width: 50%; margin: 10px auto; margin-top: 20px; word-break: break-all;\"\r\n                    [style.color]=\"titleColor\" [style.fontSize]=\"titleSize\">\r\n                    {{title}}\r\n                </h1>\r\n                <div style=\"width: 50%; margin: 10px auto; word-break: break-all;\" *ngIf=\"subTitle\"\r\n                    [style.color]=\"subTitleColor\" [style.fontSize]=\"subTitleSize\">{{subTitle}}</div>\r\n            </div>\r\n        </div>\r\n    </ng-template>\r\n</div>", styles: [".custom-loader{position:fixed;top:0;left:0;width:100%;height:100%;background:var(--background-color);color:#fff;z-index:99999;transition:all .3s linear}.custom-loader .custom-loader-section{text-align:center;width:100%;color:#f8f9fa}.custom-loader ::ng-deep>*{vertical-align:middle;white-space:normal;display:inline-block;z-index:99999999999}.vertical-center:before{content:\"\";display:inline-block;vertical-align:middle;width:0;height:100%}\n"] }]
        }], ctorParameters: function () { return [{ type: NgxHttpLoaderInterceptor }, { type: NgxHttpLoaderService }, { type: i3.DomSanitizer }]; }, propDecorators: { customTemplate: [{
                type: Input
            }], customLoader: [{
                type: Input
            }], loader: [{
                type: Input
            }], filterUrlRegexPatterns: [{
                type: Input
            }], filterUrls: [{
                type: Input
            }], filterHttpHeaders: [{
                type: Input
            }], filterHttpMethods: [{
                type: Input
            }], delay: [{
                type: Input
            }], extraDelay: [{
                type: Input
            }], minDuration: [{
                type: Input
            }], opacity: [{
                type: Input
            }], backdropBackgroundColor: [{
                type: Input
            }], iconColor: [{
                type: Input
            }], title: [{
                type: Input
            }], titleColor: [{
                type: Input
            }], titleSize: [{
                type: Input
            }], subTitle: [{
                type: Input
            }], subTitleColor: [{
                type: Input
            }], subTitleSize: [{
                type: Input
            }], custom: [{
                type: Input
            }] } });

class NgxHttpLoaderModule {
    static forRoot() {
        return {
            ngModule: NgxHttpLoaderModule,
            providers: [
                RequestsInterceptorProvider,
            ]
        };
    }
}
NgxHttpLoaderModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
NgxHttpLoaderModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderModule, declarations: [NgxHttpLoaderComponent,
        GearLoaderComponent,
        GridLoaderComponent,
        DualRingLoaderComponent,
        ClockLoaderComponent,
        DefaultLoaderComponent,
        EllipsisLoaderComponent,
        FacebookLoaderComponent,
        HeartLoaderComponent,
        HourglassLoaderComponent,
        RingLoaderComponent,
        RippleLoaderComponent,
        RollerLoaderComponent,
        SpinnerLoaderComponent,
        WaterWaveLoaderComponent,
        ThreeBounceLoaderComponent,
        MulticircleLoaderComponent,
        JellyboxLoaderComponent,
        RotatingPlaneComponent], imports: [CommonModule], exports: [NgxHttpLoaderComponent] });
NgxHttpLoaderModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderModule, imports: [[
            CommonModule
        ]] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "13.3.10", ngImport: i0, type: NgxHttpLoaderModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        NgxHttpLoaderComponent,
                        GearLoaderComponent,
                        GridLoaderComponent,
                        DualRingLoaderComponent,
                        ClockLoaderComponent,
                        DefaultLoaderComponent,
                        EllipsisLoaderComponent,
                        FacebookLoaderComponent,
                        HeartLoaderComponent,
                        HourglassLoaderComponent,
                        RingLoaderComponent,
                        RippleLoaderComponent,
                        RollerLoaderComponent,
                        SpinnerLoaderComponent,
                        WaterWaveLoaderComponent,
                        ThreeBounceLoaderComponent,
                        MulticircleLoaderComponent,
                        JellyboxLoaderComponent,
                        RotatingPlaneComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [NgxHttpLoaderComponent]
                }]
        }] });

/*
 * Public API Surface of ngx-http-loader
 */

/**
 * Generated bundle index. Do not edit.
 */

export { NgxHttpLoaderComponent, NgxHttpLoaderModule, NgxHttpLoaderService };
//# sourceMappingURL=ngx-http-loader.mjs.map
